@@ -64,7 +64,10 @@ class Logger:
         if app.devtools is None or not app.devtools.is_connected:
             return
 
-        previous_frame = inspect.currentframe().f_back
+        current_frame = inspect.currentframe()
+        assert current_frame is not None
+        previous_frame = current_frame.f_back
+        assert previous_frame is not None
         caller = inspect.getframeinfo(previous_frame)
 
         _log = self._log or app._log
