@@ -893,10 +893,7 @@ class Compositor:
             widget: Widget to update.
 
         """
-        if not self._full_map_invalidated and not widgets.issuperset(
-            self.visible_widgets
-        ):
-            self._full_map_invalidated = True
+        self._full_map_invalidated = True
         regions: list[Region] = []
         add_region = regions.append
         get_widget = self.visible_widgets.__getitem__
