@@ -3,17 +3,18 @@ Timer context manager, only used in debug.
 
 """
 
-from time import time
-
 import contextlib
+from time import perf_counter
 from typing import Generator
 
+from . import log
+
 
 @contextlib.contextmanager
 def timer(subject: str = "time") -> Generator[None, None, None]:
     """print the elapsed time. (only used in debugging)"""
-    start = time()
+    start = perf_counter()
     yield
-    elapsed = time() - start
+    elapsed = perf_counter() - start
     elapsed_ms = elapsed * 1000
-    print(f"{subject} elapsed {elapsed_ms:.2f}ms")
+    log(f"{subject} elapsed {elapsed_ms:.2f}ms")
