@@ -1,6 +1,6 @@
 from textual.app import App, ComposeResult
 from textual.constants import BORDERS
-from textual.containers import Vertical
+from textual.containers import VerticalScroll
 from textual.widgets import Button, Label
 
 TEXT = """I must not fear.
@@ -12,7 +12,7 @@ And when it has gone past, I will turn the inner eye to see its path.
 Where the fear has gone there will be nothing. Only I will remain."""
 
 
-class BorderButtons(Vertical):
+class BorderButtons(VerticalScroll):
     DEFAULT_CSS = """
     BorderButtons {
         dock: left;
@@ -46,6 +46,7 @@ class BorderApp(App):
         height: auto;
         background: $panel;
         color: $text;
+        border-title-align: center;
     }
     """
 
@@ -53,9 +54,11 @@ class BorderApp(App):
         yield BorderButtons()
         self.text = Label(TEXT, id="text")
         self.text.shrink = True
+        self.text.border_title = "solid"
         yield self.text
 
     def on_button_pressed(self, event: Button.Pressed) -> None:
+        self.text.border_title = event.button.id
         self.text.styles.border = (
             event.button.id,
             self.stylesheet._variables["secondary"],
