@@ -3,6 +3,8 @@ Constants that we might want to expose via the public API.
 
 """
 
+from __future__ import annotations
+
 import os
 
 from typing_extensions import Final
@@ -11,6 +13,8 @@ from ._border import BORDER_CHARS
 
 __all__ = ["BORDERS"]
 
+get_environ = os.environ.get
+
 
 def get_environ_bool(name: str) -> bool:
     """Check an environment variable switch.
@@ -28,3 +32,5 @@ def get_environ_bool(name: str) -> bool:
 BORDERS = list(BORDER_CHARS)
 
 DEBUG: Final[bool] = get_environ_bool("TEXTUAL_DEBUG")
+
+DRIVER: Final[str | None] = get_environ("TEXTUAL_DRIVER", None)
