@@ -205,7 +205,7 @@ class DarkSwitch(Horizontal):
     def on_mount(self) -> None:
         self.watch(self.app, "dark", self.on_dark_change, init=False)
 
-    def on_dark_change(self, dark: bool) -> None:
+    def on_dark_change(self) -> None:
         self.query_one(Switch).value = self.app.dark
 
     def on_switch_changed(self, event: Switch.Changed) -> None:
@@ -302,7 +302,7 @@ class Notification(Static):
         self.remove()
 
 
-class DemoApp(App):
+class DemoApp(App[None]):
     CSS_PATH = "demo.css"
     TITLE = "Textual Demo"
     BINDINGS = [
