@@ -224,7 +224,7 @@ class EventMonitor(threading.Thread):
 
     def run(self) -> None:
         exit_requested = self.exit_event.is_set
-        parser = XTermParser(self.target, lambda: False)
+        parser = XTermParser(lambda: False)
 
         try:
             read_count = wintypes.DWORD(0)
@@ -288,5 +288,5 @@ class EventMonitor(threading.Thread):
     def on_size_change(self, width: int, height: int) -> None:
         """Called when terminal size changes."""
         size = Size(width, height)
-        event = Resize(self.target, size, size)
-        run_coroutine_threadsafe(self.target.post_message(event), loop=self.loop)
+        event = Resize(size, size)
+        run_coroutine_threadsafe(self.target._post_message(event), loop=self.loop)
