@@ -36,7 +36,7 @@ from rich.text import Text
 from rich.traceback import Traceback
 from typing_extensions import Self
 
-from . import errors, events, messages
+from . import constants, errors, events, messages
 from ._animator import DEFAULT_EASING, Animatable, BoundAnimator, EasingFunction
 from ._arrange import DockArrangeResult, arrange
 from ._asyncio import create_task
@@ -232,6 +232,10 @@ class Widget(DOMNode):
     """Widget will highlight links automatically."""
     disabled = Reactive(False)
     """The disabled state of the widget. `True` if disabled, `False` if not."""
+    border_title = Reactive("")
+    """The one-line border title, which may contain markup to be parsed."""
+    border_subtitle = Reactive("")
+    """The one-line border subtitle, which may contain markup to be parsed."""
 
     hover_style: Reactive[Style] = Reactive(Style, repaint=False)
     highlight_link_id: Reactive[str] = Reactive("")
@@ -390,7 +394,7 @@ class Widget(DOMNode):
         compose_stack = self.app._compose_stacks[-1]
         composed = compose_stack.pop()
         if compose_stack:
-            compose_stack[-1]._nodes._append(composed)
+            compose_stack[-1].compose_add_child(composed)
         else:
             self.app._composed[-1].append(composed)
 
@@ -475,6 +479,25 @@ class Widget(DOMNode):
                 ) from exc
         raise NoMatches(f"No descendant found with id={id!r}")
 
+    def get_child_by_type(self, expect_type: type[ExpectType]) -> ExpectType:
+        """Get a child of a give type.
+
+        Args:
+            expect_type: The type of the expected child.
+
+        Raises:
+            NoMatches: If no valid child is found.
+
+        Returns:
+            A widget.
+        """
+        for child in self._nodes:
+            # We want the child with the exact type (not subclasses)
+            if type(child) is expect_type:
+                assert isinstance(child, expect_type)
+                return child
+        raise NoMatches(f"No immediate child of type {expect_type}; {self._nodes}")
+
     def get_component_rich_style(self, name: str, *, partial: bool = False) -> Style:
         """Get a *Rich* style for a component.
 
@@ -496,6 +519,24 @@ class Widget(DOMNode):
 
         return partial_style if partial else style
 
+    def render_str(self, text_content: str | Text) -> Text:
+        """Convert str in to a Text object.
+
+        If you pass in an existing Text object it will be returned unaltered.
+
+        Args:
+            text_content: Text or str.
+
+        Returns:
+            A text object.
+        """
+        text = (
+            Text.from_markup(text_content)
+            if isinstance(text_content, str)
+            else text_content
+        )
+        return text
+
     def _arrange(self, size: Size) -> DockArrangeResult:
         """Arrange children.
 
@@ -2353,6 +2394,20 @@ class Widget(DOMNode):
         """Update the styles of the widget and its children when disabled is toggled."""
         self._update_styles()
 
+    def validate_border_title(self, title: str) -> str:
+        """Ensure we only use a single line for the border title."""
+        if not title:
+            return title
+        first, *_ = title.splitlines()
+        return first
+
+    def validate_border_subtitle(self, subtitle: str) -> str:
+        """Ensure we only use a single line for the border subtitle."""
+        if not subtitle:
+            return subtitle
+        first, *_ = subtitle.splitlines()
+        return first
+
     def _size_updated(
         self, size: Size, virtual_size: Size, container_size: Size, layout: bool = True
     ) -> bool:
@@ -2399,12 +2454,12 @@ class Widget(DOMNode):
                 height - self.scrollbar_size_horizontal
             )
             if self.vertical_scrollbar._repaint_required:
-                self.call_next(self.vertical_scrollbar.refresh)
+                self.call_later(self.vertical_scrollbar.refresh)
         if self.show_horizontal_scrollbar:
             self.horizontal_scrollbar.window_virtual_size = virtual_size.width
             self.horizontal_scrollbar.window_size = width - self.scrollbar_size_vertical
             if self.horizontal_scrollbar._repaint_required:
-                self.call_next(self.horizontal_scrollbar.refresh)
+                self.call_later(self.horizontal_scrollbar.refresh)
 
         self.scroll_x = self.validate_scroll_x(self.scroll_x)
         self.scroll_y = self.validate_scroll_y(self.scroll_y)
@@ -2589,7 +2644,7 @@ class Widget(DOMNode):
             True if the message was posted, False if this widget was closed / closing.
         """
 
-        if not self.is_running:
+        if constants.DEBUG and not self.is_running and not message.no_dispatch:
             try:
                 self.log.warning(self, f"IS NOT RUNNING, {message!r} not sent")
             except NoActiveAppError:
