@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from rich.console import Console
 from rich.segment import Segment
 from rich.style import Style
 
@@ -40,6 +41,9 @@ def test_no_styles():
         Color.parse("blue"),
         Color.parse("green"),
         content.__getitem__,
+        Console(),
+        "",
+        "",
         content_size=Size(3, 3),
     )
     style = Style.from_color(bgcolor=Color.parse("green").rich_color)
@@ -67,6 +71,9 @@ def test_border():
         Color.parse("blue"),
         Color.parse("green"),
         content.__getitem__,
+        Console(),
+        "",
+        "",
         content_size=Size(3, 3),
     )
 
@@ -98,6 +105,9 @@ def test_padding():
         Color.parse("blue"),
         Color.parse("green"),
         content.__getitem__,
+        Console(),
+        "",
+        "",
         content_size=Size(3, 3),
     )
 
@@ -130,6 +140,9 @@ def test_padding_border():
         Color.parse("blue"),
         Color.parse("green"),
         content.__getitem__,
+        Console(),
+        "",
+        "",
         content_size=Size(3, 3),
     )
 
@@ -163,6 +176,9 @@ def test_outline():
         Color.parse("blue"),
         Color.parse("green"),
         content.__getitem__,
+        Console(),
+        "",
+        "",
         content_size=Size(3, 3),
     )
 
@@ -191,6 +207,9 @@ def test_crop():
         Color.parse("blue"),
         Color.parse("green"),
         content.__getitem__,
+        Console(),
+        "",
+        "",
         content_size=Size(3, 3),
         crop=Region(2, 2, 3, 3),
     )
@@ -227,7 +246,10 @@ def test_dirty_cache() -> None:
         Color.parse("blue"),
         Color.parse("green"),
         get_content_line,
-        Size(3, 3),
+        Console(),
+        "",
+        "",
+        content_size=Size(3, 3),
     )
     assert rendered_lines == [0, 1, 2]
     del rendered_lines[:]
@@ -252,6 +274,9 @@ def test_dirty_cache() -> None:
         Color.parse("blue"),
         Color.parse("green"),
         get_content_line,
+        Console(),
+        "",
+        "",
         content_size=Size(3, 3),
     )
     assert rendered_lines == []
@@ -268,6 +293,9 @@ def test_dirty_cache() -> None:
         Color.parse("blue"),
         Color.parse("green"),
         get_content_line,
+        Console(),
+        "",
+        "",
         content_size=Size(3, 3),
     )
     assert rendered_lines == [0, 1]
