@@ -1,7 +1,9 @@
 import pytest
+from rich.text import Text
 
 from textual._node_list import DuplicateIds
 from textual.app import App, ComposeResult
+from textual.containers import Container
 from textual.css.errors import StyleValueError
 from textual.css.query import NoMatches
 from textual.geometry import Size
@@ -111,6 +113,24 @@ def test_get_child_by_id_only_immediate_descendents(parent):
         parent.get_child_by_id(id="grandchild1")
 
 
+async def test_get_child_by_type():
+    class GetChildApp(App):
+        def compose(self) -> ComposeResult:
+            yield Widget(id="widget1")
+            yield Container(
+                Label(id="label1"),
+                Widget(id="widget2"),
+                id="container1",
+            )
+
+    app = GetChildApp()
+    async with app.run_test():
+        assert app.get_child_by_type(Widget).id == "widget1"
+        assert app.get_child_by_type(Container).id == "container1"
+        with pytest.raises(NoMatches):
+            app.get_child_by_type(Label)
+
+
 def test_get_widget_by_id_no_matching_child(parent):
     with pytest.raises(NoMatches):
         parent.get_widget_by_id(id="i-dont-exist")
@@ -181,3 +201,29 @@ async def test_remove():
         await pilot.press("r")
         await pilot.pause()
     assert app.return_value == 123
+
+
+# Regression test for https://github.com/Textualize/textual/issues/2079
+async def test_remove_unmounted():
+    mounted = False
+
+    class RemoveApp(App):
+        def on_mount(self):
+            nonlocal mounted
+            label = Label()
+            label.remove()
+            mounted = True
+
+    app = RemoveApp()
+    async with app.run_test() as pilot:
+        await pilot.pause()
+        assert mounted
+
+
+def test_render_str() -> None:
+    widget = Label()
+    assert widget.render_str("foo") == Text("foo")
+    assert widget.render_str("[b]foo") == Text.from_markup("[b]foo")
+    # Text objects are passed unchanged
+    text = Text("bar")
+    assert widget.render_str(text) is text
